function [err] = readTsgSeasave(hMainFig, filename)
% readTsgSeasave( hMainFig, filename )
% Function to read TSG data in cnv file from Seasave acquisition software .
%
% Input
% -----
% hMainFig ........... Handle to the main user interface
% filename ........... Data filename
%
% Output
% ------
% err .............. 1: OK - -1 : an error occured

% TODOS:
% convert cellarray filename to char array
% fill calibration coefficients and global attributes


% use waitbar per default
% ----------------------
wbool = true;

% update waitbar title with Tex mode disable
% ------------------------------------------
if wbool
  wb = waitbar(0, {' Loading cnv files...',''});
  hchild = get(wb,'children');
  htitle = get(hchild,'title');
  set(htitle,'Interpreter','None');
end

% Get the data from the application GUI
% -------------------------------------
tsg = getappdata( hMainFig, 'tsg_data');

% Display read file info on console
% ---------------------------------
fprintf('\nREAD_CNV_FILE\n'); tic;

% test if user press cancel, no file selected
% -------------------------------------------
if isnumeric(filename)
  if filename == 0
    error('readCnv: empty filename');
  end
end

% unlike uigetfile, glog systematically returns an array of cells
% ---------------------------------------------------------------
if ~iscell(filename)
  filename = glob(filename);
end
nbrecords = length(filename);

% populate tsg.file structure
% ---------------------------
[tsg.file.pathstr, tsg.file.name, tsg.file.ext] = ...
  fileparts(filename{1});
tsg.file.type = 'CNV';

% read each file
% --------------
totalRecords = 0;

for i=1:nbrecords
  s = readCnv(filename{i});
  waitbar(i/nbrecords, wb, {' Reading file', sprintf('%s...', filename{i})});
  
  % Seabird TimeJ is the julian day from current year origin
  % --------------------------------------------------------
  origin = datenum(str2double(datestr(s.Date, 'yyyy')), 1, 1);
  
  % concat seabird data in tsg struct
  % -----------------------------------
  tsg.SSJT = vertcat(tsg.SSJT, s.t090C);
  tsg.SSPS = vertcat(tsg.SSPS, s.sal00);
  tsg.CNDC = vertcat(tsg.CNDC, s.c0Sm);
  tsg.SSTP = vertcat(tsg.SSTP, s.t3890C);
  tsg.LATX = vertcat(tsg.LATX, s.latitude);
  tsg.LONX = vertcat(tsg.LONX, s.longitude);
  tsg.DAYD = vertcat(tsg.DAYD, s.timeJ + origin - 1);
  totalRecords = totalRecords + s.Dimension;
end

% convert DATE and DAYD
% ---------------------
waitbar(1, wb, {'Please wait', ...
  sprintf('The operation is processing %6d records', totalRecords)});

% fill some aditional variables and global attribute
% --------------------------------------------------
tsg.DATE = deblank( datestr(tsg.DAYD,...
  tsg.preference.date_format_variable) );
tsg.CYCLE_MESURE = s.Cruise;
tsg.PLATFORM_NAME = s.Plateforme;

% display information on command window
% --------------------------------------
fprintf(' %d lines read ', length(tsg.DAYD));

% Display time to read file on console
% ------------------------------------
t = toc; fprintf('...done (%6.2f sec).\n\n',t);

% Close waitbar
% -------------
if wbool
  close(wb)
end

% Save the data in the application GUI
% ------------------------------------
setappdata( hMainFig, 'tsg_data', tsg );

% Everything OK
% -------------
err = 1;

end

